==> haskell-pcre-heavy-1.0.0.2-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-heavy
version:              1.0.0.2
visibility:           public
id:                   pcre-heavy-1.0.0.2-CRI1r6jRxre9uqan1TQ9iy
key:                  pcre-heavy-1.0.0.2-CRI1r6jRxre9uqan1TQ9iy
license:              LicenseRef-PublicDomain
copyright:            2015 Greg V <greg@unrelenting.technology>
maintainer:           greg@unrelenting.technology
author:               Greg V
homepage:             https://github.com/myfreeweb/pcre-heavy
synopsis:             A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  b5ddc0db0a317c01286e5832dc244779
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pcre-heavy-1.0.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pcre-heavy-1.0.0.2
hs-libraries:         HSpcre-heavy-1.0.0.2-CRI1r6jRxre9uqan1TQ9iy
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    bytestring-0.10.12.1 pcre-light-0.4.1.0-AmRTGBczTXNIp5wImHxd5c
    string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
    template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-heavy
version:              1.0.0.2
visibility:           public
id:                   pcre-heavy-1.0.0.2-DwMZrojUtmF57wWpfoLzPW
key:                  pcre-heavy-1.0.0.2-DwMZrojUtmF57wWpfoLzPW
license:              LicenseRef-PublicDomain
copyright:            2015 Greg V <greg@unrelenting.technology>
maintainer:           greg@unrelenting.technology
author:               Greg V
homepage:             https://github.com/myfreeweb/pcre-heavy
synopsis:             A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  f124d0ff5dbcd27e5cdfb8b59d748cfd
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pcre-heavy-1.0.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pcre-heavy-1.0.0.2
hs-libraries:         HSpcre-heavy-1.0.0.2-DwMZrojUtmF57wWpfoLzPW
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    bytestring-0.10.12.1 pcre-light-0.4.1.0-AmRTGBczTXNIp5wImHxd5c
    string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
    template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
